@@ -59,7 +59,7 @@ class VideoListFormatter(PrettyFormatter):
 
 class AppVideo(ReplApplication):
     APPNAME = 'video'
-    VERSION = '3.3.1'
+    VERSION = '3.6'
     COPYRIGHT = 'Copyright(C) 2010-YEAR Christophe Benz, Romain Bignon, John Obbele'
     DESCRIPTION = "Console application allowing to search for videos on various websites, " \
                   "play and download them and get information."
@@ -128,7 +128,7 @@ class AppVideo(ReplApplication):
         subprocess.call(args)
 
     def read_url(self, url):
-        r = requests.get(url, stream=True)
+        r = requests.get(url, stream=True, timeout=30)
         return r.iter_lines()
 
     def complete_download(self, text, line, *ignored):
