@@ -17,15 +17,13 @@
 
 
 from collections import OrderedDict
+import warnings
+
+from urllib3.util.request import ACCEPT_ENCODING
+ENCODINGS = [e.strip() for e in ACCEPT_ENCODING.split(',')]
 
 from woob import __version__
 
-try:
-    from requests.packages.urllib3.util.request import ACCEPT_ENCODING
-except ImportError:
-    from urllib3.util.request import ACCEPT_ENCODING
-ENCODINGS = [e.strip() for e in ACCEPT_ENCODING.split(',')]
-
 
 class Profile:
     """
@@ -47,7 +45,16 @@ class Profile:
 
 
 class Weboob(Profile):
+    """
+    .. deprecated:: 3.4
+       Don't use this profile, use :class:`Woob` instead.
+    """
+
     def __init__(self, version=None):
+        warnings.warn(
+            'This profile is deprecated and will be removed in woob 4.0. Use the Woob profile instead',
+            DeprecationWarning
+        )
         self.version = version or __version__
 
     def setup_session(self, session):
