@@ -18,6 +18,7 @@
 
 from threading import RLock
 from collections import defaultdict
+import warnings
 
 
 __all__ = ['RequestsManager']
@@ -29,8 +30,12 @@ class RequestsManager:
         self.lock = RLock()
 
     def request(self, name, *args, **kwargs):
+        warnings.warn('RequestManager will be removed in woob4', DeprecationWarning, stacklevel=2)
+
         with self.lock:
             return self.callbacks[name](*args, **kwargs)
 
     def register(self, name, callback):
+        warnings.warn('RequestManager will be removed in woob4', DeprecationWarning, stacklevel=2)
+
         self.callbacks[name] = callback
