@@ -26,6 +26,8 @@ from collections import OrderedDict, deque
 from datetime import datetime
 from optparse import IndentedHelpFormatter, OptionGroup, OptionParser
 
+import yaml
+
 from woob.capabilities.base import BaseObject, FieldNotFound, UserError, empty
 from woob.capabilities.collection import BaseCollection, CapCollection, Collection, CollectionNotFound
 from woob.core import CallErrors
@@ -36,9 +38,13 @@ from woob.tools.path import WorkingPath
 from .console import BackendNotGiven, ConsoleApplication
 from .formatters.load import FormatterLoadError, FormattersLoader
 from .results import ResultsCondition, ResultsConditionError
+from .pretty import colored
 
-__all__ = ['NotEnoughArguments', 'TooManyArguments', 'ArgSyntaxError',
-           'ReplApplication']
+
+__all__ = [
+    'NotEnoughArguments', 'TooManyArguments', 'ArgSyntaxError',
+    'ReplApplication'
+]
 
 
 class NotEnoughArguments(Exception):
@@ -113,14 +119,14 @@ class ReplApplication(ConsoleApplication, Cmd):
     COLLECTION_OBJECTS = tuple()
     """Objects to allow in do_ls / do_cd"""
 
-    woob_commands = set(['backends', 'condition', 'count', 'formatter', 'logging', 'select', 'quit', 'ls', 'cd'])
-    hidden_commands = set(['EOF'])
+    woob_commands = {'backends', 'condition', 'count', 'formatter', 'logging', 'select', 'quit', 'ls', 'cd', 'storage'}
+    hidden_commands = {'EOF'}
 
     def __init__(self):
-        super(ReplApplication, self).__init__(ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
+        super().__init__(ReplOptionParser(self.SYNOPSIS, version=self._get_optparse_version()))
 
         copyright = self.COPYRIGHT.replace('YEAR', '%d' % datetime.today().year)
-        self.intro = '\n'.join(('Welcome to %s%s%s v%s' % (self.BOLD, self.APPNAME, self.NC, self.VERSION),
+        self.intro = '\n'.join(('Welcome to %s v%s' % (colored(self.APPNAME, attrs=['bold']), self.VERSION),
                                 '',
                                 copyright,
                                 'This program is free software: you can redistribute it and/or modify',
@@ -210,8 +216,15 @@ class ReplApplication(ConsoleApplication, Cmd):
             while not backend_name:
                 print('This command works with an unique backend. Availables:')
                 for index, (name, backend) in enumerate(e.backends):
-                    print('%s%d)%s %s%-15s%s   %s' % (self.BOLD, index + 1, self.NC, self.BOLD, name, self.NC,
-                          backend.DESCRIPTION))
+                    print(
+                        '%s) %s%s' % (
+                            colored('%2d' % (index + 1), 'white', attrs=['bold']),
+                            colored('%-20s' % name, 'magenta', attrs=['bold']),
+                            colored(backend.DESCRIPTION, 'green')
+                        )
+                    )
+
+
                 i = self.ask('Select a backend to proceed with "%s"' % id)
                 if not i.isdigit():
                     if i not in dict(e.backends):
@@ -302,7 +315,7 @@ class ReplApplication(ConsoleApplication, Cmd):
     def load_backends(self, *args, **kwargs):
         self.objects = []
         self.collections = []
-        return super(ReplApplication, self).load_backends(*args, **kwargs)
+        return super().load_backends(*args, **kwargs)
 
     def main(self, argv):
         cmd_args = argv[1:]
@@ -522,7 +535,7 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         try:
             try:
-                return super(ReplApplication, self).onecmd(line)
+                return super().onecmd(line)
             except CallErrors as e:
                 return self.bcall_errors_handler(e)
             except BackendNotGiven as e:
@@ -564,7 +577,7 @@ class ReplApplication(ConsoleApplication, Cmd):
         return [name for name in super().completenames(text, *ignored) if name not in self.hidden_commands]
 
     def _shell_completion_items(self):
-        items = super(ReplApplication, self)._shell_completion_items()
+        items = super()._shell_completion_items()
         items.update(
             set(self.completenames('')) -
             set(('debug', 'condition', 'count', 'formatter', 'logging', 'select', 'quit')))
@@ -592,7 +605,7 @@ class ReplApplication(ConsoleApplication, Cmd):
           * display only proposals for words which match the
             text already written by user.
         """
-        super(ReplApplication, self).complete(text, state)
+        super().complete(text, state)
 
         # When state = 0, Cmd.complete() set the 'completion_matches' attribute by
         # calling the completion function. Then, for other states, it only tries to
@@ -617,13 +630,13 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         This method can be overridden to support more exceptions types.
         """
-        return super(ReplApplication, self).bcall_error_handler(backend, error, backtrace)
+        return super().bcall_error_handler(backend, error, backtrace)
 
     def bcall_errors_handler(self, errors, ignore=()):
         if self.interactive:
-            return super(ReplApplication, self).bcall_errors_handler(errors, 'Use "logging debug" option to print backtraces.', ignore)
+            return super().bcall_errors_handler(errors, 'Use "logging debug" option to print backtraces.', ignore)
         else:
-            return super(ReplApplication, self).bcall_errors_handler(errors, ignore=ignore)
+            return super().bcall_errors_handler(errors, ignore=ignore)
 
     # -- options related methods -------------
     def _handle_options(self):
@@ -649,7 +662,7 @@ class ReplApplication(ConsoleApplication, Cmd):
         else:
             self.condition = None
 
-        return super(ReplApplication, self)._handle_options()
+        return super()._handle_options()
 
     def get_command_help(self, command, short=False):
         try:
@@ -751,6 +764,55 @@ class ReplApplication(ConsoleApplication, Cmd):
 
         return choices
 
+    def do_storage(self, line: str) -> int:
+        """
+        storage [ACTION] [BACKEND_NAME]
+
+        Manipulation of a backend storage.
+
+            * cat           display content of the storage
+            * edit          edit the storage
+            * flush         flush storage
+        """
+        args = line.split()
+        if len(args) != 2:
+            self.do_help('storage')
+            return 1
+
+        try:
+            backend = self.woob.get_backend(args[1])
+        except KeyError:
+            print('No such backend: {args[1]}', file=self.stderr)
+            return 1
+
+        if args[0] == 'cat':
+            storage = backend.storage.get()
+            print(yaml.dump(storage), end='')
+
+            return 0
+
+        if args[0] == 'edit':
+            storage = backend.storage.get()
+            output = self.acquire_input(yaml.dump(storage), suffix='.yml')
+
+            storage = yaml.safe_load(output)
+
+            backend.storage.set(storage)
+            backend.storage.save()
+
+            print(f'Storage for backend {backend.name} has been saved.')
+            return 0
+
+        if args[0] == 'flush':
+            backend.storage.set({})
+            backend.storage.save()
+
+            print(f'Storage for backend {backend.name} has been flushed.')
+            return 0
+
+        print(f'Action not found: {args[0]}', file=self.stderr)
+        return 1
+
     def do_backends(self, line):
         """
         backends [ACTION] [BACKEND_NAME]...
@@ -856,7 +918,13 @@ class ReplApplication(ConsoleApplication, Cmd):
                             loaded = 2
                         else:
                             loaded += 1
-                print('[%s] %s%-15s%s   %s' % (loaded, self.BOLD, name, self.NC, info.description))
+                print(
+                    '[%s] %s%s' % (
+                        colored(str(loaded), attrs=['bold']),
+                        colored('%-20s' % name, 'magenta', attrs=['bold']),
+                        colored(info.description, 'green')
+                    )
+                )
 
         else:
             print('Unknown action: "%s"' % action, file=self.stderr)
